#[repr(transparent)]pub struct UserSession {
inner: TypedObjectRef<UserSession, ()>,
phantom: PhantomData<()>,
}Expand description
A user’s session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<UserSession, ()>phantom: PhantomData<()>Implementations
Sourceimpl UserSession
impl UserSession
Sourcepub fn is_current(&self) -> <Cell<bool> as Property>::Value
pub fn is_current(&self) -> <Cell<bool> as Property>::Value
Whether this is the current user session.
Sourcepub fn device_id_string(&self) -> <PhantomData<String> as Property>::Value
pub fn device_id_string(&self) -> <PhantomData<String> as Property>::Value
The ID of the user session, as a string.
Sourcepub fn display_name(&self) -> <PhantomData<String> as Property>::Value
pub fn display_name(&self) -> <PhantomData<String> as Property>::Value
The display name of the device.
Sourcepub fn display_name_or_device_id(
&self,
) -> <PhantomData<String> as Property>::Value
pub fn display_name_or_device_id( &self, ) -> <PhantomData<String> as Property>::Value
The display name of the device, or the device id as a fallback.
Sourcepub fn last_seen_ip(&self) -> <PhantomData<Option<String>> as Property>::Value
pub fn last_seen_ip(&self) -> <PhantomData<Option<String>> as Property>::Value
The last IP address used by the user session.
Sourcepub fn last_seen_ts(&self) -> <PhantomData<u64> as Property>::Value
pub fn last_seen_ts(&self) -> <PhantomData<u64> as Property>::Value
The last time the user session was used, as the number of milliseconds since Unix EPOCH.
Sourcepub fn last_seen_datetime(
&self,
) -> <PhantomData<Option<DateTime>> as Property>::Value
pub fn last_seen_datetime( &self, ) -> <PhantomData<Option<DateTime>> as Property>::Value
The last time the user session was used, as a GDateTime.
Sourcepub fn last_seen_datetime_string(
&self,
) -> <PhantomData<Option<String>> as Property>::Value
pub fn last_seen_datetime_string( &self, ) -> <PhantomData<Option<String>> as Property>::Value
The last time the user session was used, as a formatted string.
Sourcepub fn verified(&self) -> <PhantomData<bool> as Property>::Value
pub fn verified(&self) -> <PhantomData<bool> as Property>::Value
Whether this user session is verified.
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_is_current_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_current_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-current property
Sourcepub fn connect_device_id_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_device_id_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the device-id-string property
Sourcepub fn connect_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name property
Sourcepub fn connect_display_name_or_device_id_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_display_name_or_device_id_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the display-name-or-device-id property
Sourcepub fn connect_last_seen_ip_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_last_seen_ip_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the last-seen-ip property
Sourcepub fn connect_last_seen_ts_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_last_seen_ts_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the last-seen-ts property
Sourcepub fn connect_last_seen_datetime_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_last_seen_datetime_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the last-seen-datetime property
Sourcepub fn connect_last_seen_datetime_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_last_seen_datetime_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the last-seen-datetime-string property
Sourcepub fn connect_verified_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_verified_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the verified property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_is_current(&self)
pub fn notify_is_current(&self)
Notify listeners of a change in the is-current property
Sourcepub fn notify_device_id_string(&self)
pub fn notify_device_id_string(&self)
Notify listeners of a change in the device-id-string property
Sourcepub fn notify_display_name(&self)
pub fn notify_display_name(&self)
Notify listeners of a change in the display-name property
Sourcepub fn notify_display_name_or_device_id(&self)
pub fn notify_display_name_or_device_id(&self)
Notify listeners of a change in the display-name-or-device-id property
Sourcepub fn notify_last_seen_ip(&self)
pub fn notify_last_seen_ip(&self)
Notify listeners of a change in the last-seen-ip property
Sourcepub fn notify_last_seen_ts(&self)
pub fn notify_last_seen_ts(&self)
Notify listeners of a change in the last-seen-ts property
Sourcepub fn notify_last_seen_datetime(&self)
pub fn notify_last_seen_datetime(&self)
Notify listeners of a change in the last-seen-datetime property
Sourcepub fn notify_last_seen_datetime_string(&self)
pub fn notify_last_seen_datetime_string(&self)
Notify listeners of a change in the last-seen-datetime-string property
Sourcepub fn notify_verified(&self)
pub fn notify_verified(&self)
Notify listeners of a change in the verified property
Sourceimpl UserSession
impl UserSession
pub(super) fn new(session: &Session, device_id: OwnedDeviceId) -> Self
Sourcepub(super) fn set_data(&self, data: UserSessionData)
pub(super) fn set_data(&self, data: UserSessionData)
Set the user session data.
Sourcepub(crate) async fn rename(&self, display_name: String) -> Result<(), HttpError>
pub(crate) async fn rename(&self, display_name: String) -> Result<(), HttpError>
Renames the user session.
Sourcepub(crate) async fn delete(
&self,
parent: &impl IsA<Widget>,
) -> Result<(), AuthError>
pub(crate) async fn delete( &self, parent: &impl IsA<Widget>, ) -> Result<(), AuthError>
Deletes the UserSession.
Requires a widget because it might show a dialog for UIAA.
Sourcepub(super) fn emit_disconnected(&self)
pub(super) fn emit_disconnected(&self)
Signal that this session was disconnected.
Sourcepub fn connect_disconnected<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_disconnected<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when this session is disconnected.